############
kafkaconnect
############

A Python client for managing connectors using the `Kafka Connect API <https://docs.confluent.io/current/connect/references/restapi.html>`_.

Overview
========

.. include:: overview.rst

Installation
============

.. toctree::
   :maxdepth: 2

   installation

Configuration
=============

.. toctree::
   :maxdepth: 2

   configuration

User guide
==========

.. toctree::
   :maxdepth: 2

   userguide

Development guide
=================

.. toctree::
   :maxdepth: 2

   development
   release

CLI
===

.. toctree::
   :maxdepth: 2

   cli


Project information
===================

The GitHub repository for `kafka-connect-manager` is https://github.com/lsst-sqre/kafka-connect-manager

.. toctree::
   :maxdepth: 2

   contributing
   changelog

See the LICENSE_ file for licensing information.

.. _LICENSE: https://github.com/lsst-sqre/kafka-connect-manager/blob/master/LICENSE
